@@ -1,5 +1,5 @@
 /*
-  maeFat Rev 1.0
+  maeFat Rev 1.1
   Ken Young (orrery.moko@gmail.com)
   First Version Feb. 5, 2011
 
@@ -86,12 +86,14 @@ char *backupDir = "/media/mmc1/.maeFat";
 char *backupFile = "/media/mmc1/.maeFat/data";
 
 double myHeight          =  72.0;
+double myTarget          = 150.0;
 int weightkg             = FALSE;
 int heightcm             = FALSE;
 int monthFirst           = FALSE;
 int nonjudgementalColors = FALSE;
 int hackerDietMode       = FALSE;
 int showComments         = FALSE;
+int showTarget           = FALSE;
 int plotInterval         =   365;
 
 int goodColor = OR_GREEN;
@@ -104,7 +106,7 @@ char *monthName[12] = {"January",   "February", "March",    "April",
 		       "September", "October",  "November", "December"};
 char *dayName[7] = {"Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"};
 double monthLengths[12] = {31.0, 28.0, 31.0, 30.0, 31.0, 30.0, 31.0, 31.0, 30.0, 31.0, 30.0, 31.0};
-char *maeFatVersion = "1.0";
+char *maeFatVersion = "1.1";
 char scratchString[200];
 
 int displayHeight, displayWidth;
@@ -344,7 +346,7 @@ void enqueueEntry(double jD, float weight, char *comment)
 float calculateWeightedAverage1(logEntry *end)
 {
   double startTime;
-  double ave, weightSum, weight;
+  float ave, weightSum, weight;
   float p = 0.9;
   logEntry *ptr;
 
@@ -353,14 +355,14 @@ float calculateWeightedAverage1(logEntry *end)
   ave = weightSum = 0.0;
   while (ptr != NULL) {
     if ((startTime - ptr->time) < 100.0) {
-      weight = pow(p, startTime - ptr->time);
-      ave += weight * ((double)ptr->weight);
+      weight = powf(p, (float)(startTime - ptr->time));
+      ave += weight * ptr->weight;
       weightSum += weight;
     }
     ptr = ptr->last;
   }
   ave /= weightSum;
-  return((float)ave);
+  return(ave);
 }
 
 float calculateWeightedAverage2(logEntry *end)
@@ -491,12 +493,14 @@ void readSettings(char *fileName)
     if (getLine(settingsFD, TRUE, &inLine[0], &eOF))
       if (strlen(inLine) > 0) {
 	tokenCheck(inLine, "MY_HEIGHT",          DOUBLE_TOKEN, &myHeight);
+	tokenCheck(inLine, "MY_TARGET",          DOUBLE_TOKEN, &myTarget);
 	tokenCheck(inLine, "WEIGHT_KG",             INT_TOKEN, &weightkg);
 	tokenCheck(inLine, "HEIGHT_CM",             INT_TOKEN, &heightcm);
 	tokenCheck(inLine, "MONTH_FIRST",           INT_TOKEN, &monthFirst);
 	tokenCheck(inLine, "NONJUDGEMENTAL_COLORS", INT_TOKEN, &nonjudgementalColors);
 	tokenCheck(inLine, "HACKER_DIET_MODE",      INT_TOKEN, &hackerDietMode);
 	tokenCheck(inLine, "SHOW_COMMENTS",         INT_TOKEN, &showComments);
+	tokenCheck(inLine, "SHOW_TARGET",           INT_TOKEN, &showTarget);
 	tokenCheck(inLine, "PLOT_INTERVAL",         INT_TOKEN, &plotInterval);
       }
   }
@@ -551,6 +555,12 @@ void calcMaxima(double startTJD)
   }
   plotMaxX = maxJD + BORDER_FACTOR_X*(maxJD-minJD);
   plotMinX = minJD - BORDER_FACTOR_X*(maxJD-minJD);
+  if (showTarget) {
+    if (maxWeight < myTarget)
+      maxWeight = myTarget;
+    else if (minWeight > myTarget)
+      minWeight = myTarget;
+  }
   plotMaxY = maxWeight + BORDER_FACTOR_Y*(maxWeight-minWeight);
   plotMinY = minWeight - BORDER_FACTOR_Y*(maxWeight-minWeight);
 }
@@ -944,6 +954,15 @@ void redrawScreen(void)
 	  gdk_draw_line(pixmap, gC[OR_WHITE], x, y, x-stub, y);
 	}
       }
+      if (showTarget) {
+	int x0, y0, x1, y1;
+
+	screenCoordinates(plotMinX, myTarget, &x0, &y0);
+	screenCoordinates(plotMaxX, myTarget, &x1, &y1);
+	gdk_draw_line(pixmap, gC[OR_GREEN], x0, y0-1, x1, y1-1);
+	gdk_draw_line(pixmap, gC[OR_GREEN], x0, y0,   x1, y1);
+	gdk_draw_line(pixmap, gC[OR_GREEN], x0, y0+1, x1, y1+1);
+      }
     }
     /* X axis labelling */
     tJDToDate(logRoot->time, &sYear, &sMonth, &sDay);
@@ -2002,12 +2021,14 @@ void writeSettings(void)
     return;
   }
   fprintf(settings, "MY_HEIGHT %5.1f\n",          myHeight);
+  fprintf(settings, "MY_TARGET %5.1f\n",          myTarget);
   fprintf(settings, "WEIGHT_KG %d\n",             weightkg);
   fprintf(settings, "HEIGHT_CM %d\n",             heightcm);
   fprintf(settings, "MONTH_FIRST %d\n",           monthFirst);
   fprintf(settings, "NONJUDGEMENTAL_COLORS %d\n", nonjudgementalColors);
   fprintf(settings, "HACKER_DIET_MODE %d\n",      hackerDietMode);
   fprintf(settings, "SHOW_COMMENTS %d\n",         showComments);
+  fprintf(settings, "SHOW_TARGET %d\n",           showTarget);
   fprintf(settings, "PLOT_INTERVAL %d\n",         plotInterval);
   fclose(settings);
 }
@@ -2016,12 +2037,13 @@ GtkWidget *heightSpinLabel, *heightSpin, *weightUnitLabel, *heightUnitLabel,
   *dateFormatLabel, *poundsButton, *kgButton, *inButton, *cmButton, *dayButton,
   *monthButton, *nonjudgementalButton, *hackerDietButton, *showCommentsButton,
   *plotWeekButton, *plotMonthButton, *plotQuarterButton, *plot6MonthButton,
-  *plotYearButton, *plotHistoryButton;
+  *plotYearButton, *plotHistoryButton, *targetSpinLabel, *targetSpin, *showTargetButton;
 
 void checkSettings(void)
 {
   dprintf("In checkSettings\n");
   myHeight = gtk_spin_button_get_value((GtkSpinButton *)heightSpin);
+  myTarget = gtk_spin_button_get_value((GtkSpinButton *)targetSpin);
   if (GTK_TOGGLE_BUTTON(plotWeekButton)->active)
     plotInterval = 14;
   else if (GTK_TOGGLE_BUTTON(plotMonthButton)->active)
@@ -2054,6 +2076,10 @@ void checkSettings(void)
     showComments = TRUE;
   else
     showComments = FALSE;
+  if (GTK_TOGGLE_BUTTON(showTargetButton)->active)
+    showTarget = TRUE;
+  else
+    showTarget = FALSE;
   if (GTK_TOGGLE_BUTTON(cmButton)->active)
     heightcm = TRUE;
   else
@@ -2070,10 +2096,10 @@ void settingsButtonClicked(GtkButton *button, gpointer userData)
 {
   static GtkWidget *settingsTable;
   static GSList *weightGroup, *heightGroup, *dateGroup, *plotGroup;
-  static GtkObject *heightAdjustment;
+  static GtkObject *heightAdjustment, *targetAdjustment;
 
   dprintf("in settingsButtonClicked()\n");
-  settingsTable = gtk_table_new(3, 7, FALSE);
+  settingsTable = gtk_table_new(3, 8, FALSE);
 
   heightUnitLabel = gtk_label_new("Height Unit");
   gtk_table_attach(GTK_TABLE(settingsTable), (GtkWidget *)heightUnitLabel, 0, 1, 0, 1,
@@ -2116,8 +2142,24 @@ void settingsButtonClicked(GtkButton *button, gpointer userData)
   gtk_table_attach(GTK_TABLE(settingsTable), (GtkWidget *)kgButton, 2, 3, 2, 3,
 		   GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
 
+  targetSpinLabel = gtk_label_new("Target Weight");
+  gtk_table_attach(GTK_TABLE(settingsTable), (GtkWidget *)targetSpinLabel, 0, 1, 3, 4,
+		   GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+  targetAdjustment = gtk_adjustment_new(myTarget, 60.0, 250.0, 0.5, 1.0, 0.0);
+  targetSpin = gtk_spin_button_new((GtkAdjustment *)targetAdjustment, 0.5, 1);
+  gtk_spin_button_set_numeric((GtkSpinButton *)targetSpin, TRUE);
+  gtk_table_attach(GTK_TABLE(settingsTable), (GtkWidget *)targetSpin, 1, 2, 3, 4,
+		   GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+  showTargetButton = gtk_check_button_new_with_label("Plot Target Weight");
+  if (showTarget)
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(showTargetButton), TRUE);
+  else
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(showTargetButton), FALSE);
+  gtk_table_attach(GTK_TABLE(settingsTable), showTargetButton, 2, 3, 3, 4,
+		   GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+
   dateFormatLabel = gtk_label_new("Date Format");
-  gtk_table_attach(GTK_TABLE(settingsTable), (GtkWidget *)dateFormatLabel, 0, 1, 3, 4,
+  gtk_table_attach(GTK_TABLE(settingsTable), (GtkWidget *)dateFormatLabel, 0, 1, 4, 5,
 		   GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
   dayButton = gtk_radio_button_new_with_label(NULL, "dd/mm/yyyy");
   dateGroup = gtk_radio_button_group(GTK_RADIO_BUTTON(dayButton));
@@ -2127,9 +2169,9 @@ void settingsButtonClicked(GtkButton *button, gpointer userData)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(monthButton), TRUE);
   else
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dayButton), TRUE);
-  gtk_table_attach(GTK_TABLE(settingsTable), (GtkWidget *)dayButton, 1, 2, 3, 4,
+  gtk_table_attach(GTK_TABLE(settingsTable), (GtkWidget *)dayButton, 1, 2, 4, 5,
 		   GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
-  gtk_table_attach(GTK_TABLE(settingsTable), (GtkWidget *)monthButton, 2, 3, 3, 4,
+  gtk_table_attach(GTK_TABLE(settingsTable), (GtkWidget *)monthButton, 2, 3, 4, 5,
 		   GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
 
   nonjudgementalButton = gtk_check_button_new_with_label("Nonjudgemental Colors");
@@ -2137,21 +2179,21 @@ void settingsButtonClicked(GtkButton *button, gpointer userData)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(nonjudgementalButton), TRUE);
   else
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(nonjudgementalButton), FALSE);
-  gtk_table_attach(GTK_TABLE(settingsTable), nonjudgementalButton, 0, 1, 4, 5,
+  gtk_table_attach(GTK_TABLE(settingsTable), nonjudgementalButton, 0, 1, 5, 6,
 		   GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
   hackerDietButton = gtk_check_button_new_with_label("Hacker Diet Mode");
   if (hackerDietMode)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(hackerDietButton), TRUE);
   else
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(hackerDietButton), FALSE);
-  gtk_table_attach(GTK_TABLE(settingsTable), hackerDietButton, 1, 2, 4, 5,
+  gtk_table_attach(GTK_TABLE(settingsTable), hackerDietButton, 1, 2, 5, 6,
 		   GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
   showCommentsButton = gtk_check_button_new_with_label("Plot Comments");
   if (showComments)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(showCommentsButton), TRUE);
   else
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(showCommentsButton), FALSE);
-  gtk_table_attach(GTK_TABLE(settingsTable), showCommentsButton, 2, 3, 4, 5,
+  gtk_table_attach(GTK_TABLE(settingsTable), showCommentsButton, 2, 3, 5, 6,
 		   GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
 
   plotWeekButton = gtk_radio_button_new_with_label(NULL, "Plot Last 2 Weeks");
@@ -2185,17 +2227,17 @@ void settingsButtonClicked(GtkButton *button, gpointer userData)
   default:
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(plotHistoryButton), TRUE);
   }
-  gtk_table_attach(GTK_TABLE(settingsTable), plotWeekButton, 0, 1, 5, 6,
+  gtk_table_attach(GTK_TABLE(settingsTable), plotWeekButton, 0, 1, 6, 7,
 		   GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
-  gtk_table_attach(GTK_TABLE(settingsTable), plotMonthButton, 1, 2, 5, 6,
+  gtk_table_attach(GTK_TABLE(settingsTable), plotMonthButton, 1, 2, 6, 7,
 		   GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
-  gtk_table_attach(GTK_TABLE(settingsTable), plotQuarterButton, 2, 3, 5, 6,
+  gtk_table_attach(GTK_TABLE(settingsTable), plotQuarterButton, 2, 3, 6, 7,
 		   GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
-  gtk_table_attach(GTK_TABLE(settingsTable), plot6MonthButton, 0, 1, 6, 7,
+  gtk_table_attach(GTK_TABLE(settingsTable), plot6MonthButton, 0, 1, 7, 8,
 		   GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
-  gtk_table_attach(GTK_TABLE(settingsTable), plotYearButton, 1, 2, 6, 7,
+  gtk_table_attach(GTK_TABLE(settingsTable), plotYearButton, 1, 2, 7, 8,
 		   GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
-  gtk_table_attach(GTK_TABLE(settingsTable), plotHistoryButton, 2, 3, 6, 7,
+  gtk_table_attach(GTK_TABLE(settingsTable), plotHistoryButton, 2, 3, 7, 8,
 		   GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
 
   settingsStackable = hildon_stackable_window_new();
@@ -2220,7 +2262,7 @@ void aboutButtonClicked(GtkButton *button, gpointer userData)
   dprintf("in aboutButtonClicked()\n");
   if (firstCall) {
     aboutBuffer = gtk_text_buffer_new(NULL);
-    gtk_text_buffer_set_text(aboutBuffer, "maeFat Version 1.0\nCopyright (C) 2011, Ken Young\n\nThis program helps you keep track of your weight.\nThis is free, open source software, released under GPL version 2.\n\nPlease send comments, questions and feature requests to\norrery.moko@gmail.com", -1);
+    gtk_text_buffer_set_text(aboutBuffer, "maeFat Version 1.1\nCopyright (C) 2011, Ken Young\n\nThis program helps you keep track of your weight.\nThis is free, open source software, released under GPL version 2.\n\nPlease send comments, questions and feature requests to\norrery.moko@gmail.com", -1);
     aboutTextWidget = hildon_text_view_new(); 
     ((GtkTextView *)aboutTextWidget)->editable =
       ((GtkTextView *)aboutTextWidget)->cursor_visible = FALSE;
@@ -2372,7 +2414,7 @@ void createEditPage(logEntry *ptr)
   dataEditTable = gtk_table_new(1, 5, FALSE);
   dateEditButton = hildon_date_button_new(HILDON_SIZE_AUTO, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
   tJDToDate((double)((int)ptr->time), &year, &month, &day);
-  hildon_date_button_set_date(dateEditButton, year, month-1, day);
+  hildon_date_button_set_date((HildonDateButton *)dateEditButton, year, month-1, day);
   gtk_table_attach(GTK_TABLE(dataEditTable), dateEditButton, 0, 1, 0, 1,
 		   GTK_EXPAND, GTK_EXPAND, 0, 0);
   
@@ -2380,7 +2422,7 @@ void createEditPage(logEntry *ptr)
   dayFrac = ptr->time - (double)((int)ptr->time);
   hours = (int)(dayFrac*24.0);
   minutes = (int)((dayFrac - ((double)hours)/24.0) * 1440.0 + 0.5);
-  hildon_time_button_set_time(timeEditButton, hours, minutes);
+  hildon_time_button_set_time((HildonTimeButton *)timeEditButton, hours, minutes);
   gtk_table_attach(GTK_TABLE(dataEditTable), timeEditButton, 0, 1, 1, 2,
 		   GTK_EXPAND, GTK_EXPAND, 0, 0);
   dataEditStackable = hildon_stackable_window_new();
